# Introduction

This is the API documentation of the Isso commenting system.
**[Click here](/docs/)** to get back to the regular **Isso documentation**.

### What can you do?

- Fetch comment threads
- Post, edit and delete comments
- Get information about the server
- Like and dislike comments
- ...and much more!

### Technical details

These API docs are automatically generated by [apiDoc][apidoc] from
[isso/views/comments.py](https://github.com/isso-comments/isso/blob/master/isso/views/comments.py).

You can select previous versions from a dropdown on the upper right of the
page.

For more information about Isso, visit **[isso-comments.de](https://isso-comments.de)**
or check out the source at **[GitHub](https://github.com/isso-comments/isso)**.

[apiDoc]: https://apidocjs.com/

### Conventions

This documenation uses `https://comments.example.com` as the base URL for Isso's API.

For your installation, this URL will be different. Make sure to substitute the
example URL for the URL you load your `embed.min.js` from.

E.g. `https://example.com/isso/js/embed.min.js` would result in a base URL of
`https://example.com/isso`.
